# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2015-12-15 14:46
from __future__ import unicode_literals

import audiofield.fields
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='AudioFile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(help_text='audio file label', max_length=150, verbose_name='audio name')),
                ('audio_file', audiofield.fields.AudioField(blank=True, upload_to=b'upload/audiofiles', verbose_name='audio file')),
                ('created_date', models.DateTimeField(auto_now_add=True)),
                ('updated_date', models.DateTimeField(auto_now=True)),
                ('user', models.ForeignKey(help_text='select user', on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='user')),
            ],
            options={
                'db_table': 'audio_file',
                'verbose_name': 'audio file',
                'verbose_name_plural': 'audio files',
                'permissions': (('view_audiofile', 'can see Audio Files'),),
            },
        ),
    ]
